@@ -1,5 +1,5 @@
 package Bitcoin::Crypto;
-$Bitcoin::Crypto::VERSION = '3.002';
+$Bitcoin::Crypto::VERSION = '4.000';
 use v5.10;
 use strict;
 use warnings;
@@ -11,6 +11,8 @@ our @EXPORT_OK = qw(
 	btc_extpub
 	btc_pub
 	btc_script
+	btc_tapscript
+	btc_script_tree
 	btc_transaction
 	btc_block
 	btc_utxo
@@ -49,6 +51,18 @@ sub btc_script
 	return 'Bitcoin::Crypto::Script';
 }
 
+sub btc_tapscript
+{
+	require Bitcoin::Crypto::Tapscript;
+	return 'Bitcoin::Crypto::Tapscript';
+}
+
+sub btc_script_tree
+{
+	require Bitcoin::Crypto::Script::Tree;
+	return 'Bitcoin::Crypto::Script::Tree';
+}
+
 sub btc_transaction
 {
 	require Bitcoin::Crypto::Transaction;
@@ -91,7 +105,7 @@ Bitcoin::Crypto - Bitcoin cryptography in Perl
 
 	my $master_key = btc_extprv->from_mnemonic($mnemonic);
 	my $derived_key = $master_key->derive_key_bip44(
-		purpose => Bitcoin::Crypto::Constants::bip44_segwit_purpose,
+		purpose => Bitcoin::Crypto::Constants::bip44_taproot_purpose,
 		index => 0,
 	);
 
@@ -112,9 +126,9 @@ L<Bitcoin::Crypto::Manual> for an overview of the module.
 =head1 SHORTCUT FUNCTIONS
 
 This package exports the following functions when asked for them. These are
-shourtcut functions and will load needed packages and return their names. You
+shortcut functions and will load needed packages and return their names. You
 can then use names of loaded packages to instantiate them however you want.
-It's also possible to load all of them with the I<:all> tag in import. They
+It's also possible to load all of them with the C<:all> tag in import. These
 functions can be used as follows:
 
 	use Bitcoin::Crypto qw(btc_pub);
@@ -143,6 +157,14 @@ Loads L<Bitcoin::Crypto::Key::Public>
 
 Loads L<Bitcoin::Crypto::Script>
 
+=head2 btc_tapscript
+
+Loads L<Bitcoin::Crypto::Tapscript>
+
+=head2 btc_script_tree
+
+Loads L<Bitcoin::Crypto::Script::Tree>
+
 =head2 btc_transaction
 
 Loads L<Bitcoin::Crypto::Transaction>
@@ -185,7 +207,7 @@ In no particular order:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018 - 2024 by Bartosz Jarzyna
+Copyright (C) 2018 - 2025 by Bartosz Jarzyna
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
