@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::DerivationPath;
-$Bitcoin::Crypto::DerivationPath::VERSION = '3.002';
+$Bitcoin::Crypto::DerivationPath::VERSION = '4.000';
 use v5.10;
 use strict;
 use warnings;
@@ -11,6 +11,8 @@ use Types::Common -sigs, -types;
 use Bitcoin::Crypto::Constants;
 use Bitcoin::Crypto::Exception;
 
+use namespace::clean;
+
 has param 'private' => (
 	isa => Bool,
 );
@@ -56,9 +58,9 @@ sub get_path_hardened
 	];
 }
 
-signature_for get_path_hardened => (
-	method => Object,
-	positional => [],
+signature_for from_string => (
+	method => Str,
+	positional => [Str],
 );
 
 sub from_string
@@ -175,7 +177,7 @@ A helper which returns self.
 
 Returns an array reference. Each item in the array is an array reference with
 two values, where the first one is the path key and the second one is a boolean
-indicating whether that key is hardened. The first value will always be within
-the range C<0 .. 2^31 - 1> (unlike L</path>, which has keys larger than that
-for hardened keys).
+indicating whether that key is hardened. The first value of each element will
+always be within the range C<0 .. 2^31 - 1> (unlike L</path>, which has keys
+larger than that for hardened keys).
 
