@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::Exception;
-$Bitcoin::Crypto::Exception::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::VERSION = '4.000';
 use v5.10;
 use strict;
 use warnings;
@@ -101,7 +101,7 @@ sub as_string
 {
 
 	package Bitcoin::Crypto::Exception::Transaction;
-$Bitcoin::Crypto::Exception::Transaction::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::Transaction::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 
 }
@@ -109,7 +109,7 @@ use parent -norequire, 'Bitcoin::Crypto::Exception';
 {
 
 	package Bitcoin::Crypto::Exception::UTXO;
-$Bitcoin::Crypto::Exception::UTXO::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::UTXO::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 
 }
@@ -117,134 +117,134 @@ use parent -norequire, 'Bitcoin::Crypto::Exception';
 {
 
 	package Bitcoin::Crypto::Exception::Sign;
-$Bitcoin::Crypto::Exception::Sign::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::Sign::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 
 }
 
-{
-
-	package Bitcoin::Crypto::Exception::Verify;
-$Bitcoin::Crypto::Exception::Verify::VERSION = '3.002';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
-}
-
 {
 
 	package Bitcoin::Crypto::Exception::KeyCreate;
-$Bitcoin::Crypto::Exception::KeyCreate::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::KeyCreate::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::KeyDerive;
-$Bitcoin::Crypto::Exception::KeyDerive::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::KeyDerive::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::MnemonicGenerate;
-$Bitcoin::Crypto::Exception::MnemonicGenerate::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::MnemonicGenerate::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::MnemonicCheck;
-$Bitcoin::Crypto::Exception::MnemonicCheck::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::MnemonicCheck::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Base58;
-$Bitcoin::Crypto::Exception::Base58::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::Base58::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Base58InputFormat;
-$Bitcoin::Crypto::Exception::Base58InputFormat::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::Base58InputFormat::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception::Base58';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Base58InputChecksum;
-$Bitcoin::Crypto::Exception::Base58InputChecksum::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::Base58InputChecksum::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception::Base58';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Bech32;
-$Bitcoin::Crypto::Exception::Bech32::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::Bech32::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Bech32InputFormat;
-$Bitcoin::Crypto::Exception::Bech32InputFormat::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::Bech32InputFormat::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception::Bech32';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Bech32InputData;
-$Bitcoin::Crypto::Exception::Bech32InputData::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::Bech32InputData::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception::Bech32';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Bech32InputChecksum;
-$Bitcoin::Crypto::Exception::Bech32InputChecksum::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::Bech32InputChecksum::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception::Bech32';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::SegwitProgram;
-$Bitcoin::Crypto::Exception::SegwitProgram::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::SegwitProgram::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::ScriptType;
-$Bitcoin::Crypto::Exception::ScriptType::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::ScriptType::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::ScriptOpcode;
-$Bitcoin::Crypto::Exception::ScriptOpcode::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::ScriptOpcode::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::ScriptPush;
-$Bitcoin::Crypto::Exception::ScriptPush::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::ScriptPush::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Block;
-$Bitcoin::Crypto::Exception::Block::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::Block::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
-	package Bitcoin::Crypto::Exception::ScriptSyntax;
-$Bitcoin::Crypto::Exception::ScriptSyntax::VERSION = '3.002';
+	package Bitcoin::Crypto::Exception::ScriptTree;
+$Bitcoin::Crypto::Exception::ScriptTree::VERSION = '4.000';
+use parent -norequire, 'Bitcoin::Crypto::Exception';
+}
+
+{
+
+	package Bitcoin::Crypto::Exception::ScriptCompilation;
+$Bitcoin::Crypto::Exception::ScriptCompilation::VERSION = '4.000';
 use Moo;
 	use Mooish::AttributeBuilder -standard;
 	use Types::Common -types;
@@ -278,17 +278,31 @@ use Moo;
 	}
 }
 
+{
+
+	package Bitcoin::Crypto::Exception::ScriptSyntax;
+$Bitcoin::Crypto::Exception::ScriptSyntax::VERSION = '4.000';
+use parent -norequire, 'Bitcoin::Crypto::Exception::ScriptCompilation';
+}
+
+{
+
+	package Bitcoin::Crypto::Exception::ScriptSuccess;
+$Bitcoin::Crypto::Exception::ScriptSuccess::VERSION = '4.000';
+use parent -norequire, 'Bitcoin::Crypto::Exception::ScriptCompilation';
+}
+
 {
 
 	package Bitcoin::Crypto::Exception::ScriptRuntime;
-$Bitcoin::Crypto::Exception::ScriptRuntime::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::ScriptRuntime::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::TransactionScript;
-$Bitcoin::Crypto::Exception::TransactionScript::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::TransactionScript::VERSION = '4.000';
 use parent -norequire,
 		'Bitcoin::Crypto::Exception::Transaction',
 		'Bitcoin::Crypto::Exception::ScriptRuntime';
@@ -297,35 +311,35 @@ use parent -norequire,
 {
 
 	package Bitcoin::Crypto::Exception::NetworkCheck;
-$Bitcoin::Crypto::Exception::NetworkCheck::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::NetworkCheck::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::NetworkConfig;
-$Bitcoin::Crypto::Exception::NetworkConfig::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::NetworkConfig::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Address;
-$Bitcoin::Crypto::Exception::Address::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::Address::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::AddressGenerate;
-$Bitcoin::Crypto::Exception::AddressGenerate::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::AddressGenerate::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception::Address';
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::PSBT;
-$Bitcoin::Crypto::Exception::PSBT::VERSION = '3.002';
+$Bitcoin::Crypto::Exception::PSBT::VERSION = '4.000';
 use parent -norequire, 'Bitcoin::Crypto::Exception';
 }
 
@@ -353,7 +367,7 @@ Bitcoin::Crypto::Exception - Exception classes for Bitcoin::Crypto
 
 =head1 DESCRIPTION
 
-An exception wrapper class with automatic stringification and standarized
+An exception wrapper class with automatic stringification and standardized
 raising.
 
 Contains inline packages that identify parts that went wrong (like
