@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::Role::Network;
-$Bitcoin::Crypto::Role::Network::VERSION = '3.002';
+$Bitcoin::Crypto::Role::Network::VERSION = '4.000';
 use v5.10;
 use strict;
 use warnings;
@@ -28,16 +28,17 @@ sub _trigger_network
 	if (Bitcoin::Crypto::Network->single_network) {
 		my $default = Bitcoin::Crypto::Network->get;
 		Bitcoin::Crypto::Exception::NetworkCheck->raise(
-			'invalid network, running in single-network mode with ' . $default->id
+			sprintf 'invalid network %s, running in single-network mode with %s', $self->network->id, $default->id
 		) if $default->id ne $self->network->id;
 	}
 }
 
-# make writer chainable
 sub set_network
 {
 	my ($self, $network) = @_;
 	$self->_set_network($network);
+
+	# chainable - undocumented behavior, but kept for backcompat
 	return $self;
 }
 
