@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Tapscript;
-$Bitcoin::Crypto::Tapscript::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::Tapscript::VERSION = '3.9991';
+$Bitcoin::Crypto::Tapscript::VERSION = '4.000';
 use v5.10;
 use strict;
 use warnings;
@@ -38,10 +37,13 @@ Bitcoin::Crypto::Tapscript - Bitcoin script subclass for tapscripts
 =head1 DESCRIPTION
 
 This is a L<Bitcoin::Crypto::Script> subclass used for dealing with tapscripts.
+The main difference between scripts and tapscripts is a slightly different set
+of opcodes.
 
 =head1 METHODS
 
 =head2 opcode_class
 
-This method overrides the parent's version and returns L<Bitcoin::Crypto::Tapscript::Opcode>.
+This method overrides the parent's version and returns
+L<Bitcoin::Crypto::Tapscript::Opcode>.
 
