@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::Transaction::Output;
-$Bitcoin::Crypto::Transaction::Output::VERSION = '3.002';
+$Bitcoin::Crypto::Transaction::Output::VERSION = '4.000';
 use v5.10;
 use strict;
 use warnings;
@@ -209,7 +209,7 @@ I<writer>: C<set_locking_script>
 
 =head3 new
 
-	$block = $class->new(%args)
+	$output = $class->new(%args)
 
 This is a standard Moo constructor, which can be used to create the object. It
 takes arguments specified in L</Attributes>.
